@@ -186,17 +186,17 @@ typedef struct {
 
 static int jpc_dec_dump(jpc_dec_t *dec, FILE *out);
 
-jpc_ppxstab_t *jpc_ppxstab_create();
+jpc_ppxstab_t *jpc_ppxstab_create(void);
 void jpc_ppxstab_destroy(jpc_ppxstab_t *tab);
 int jpc_ppxstab_grow(jpc_ppxstab_t *tab, int maxents);
 int jpc_ppxstab_insert(jpc_ppxstab_t *tab, jpc_ppxstabent_t *ent);
 jpc_streamlist_t *jpc_ppmstabtostreams(jpc_ppxstab_t *tab);
 int jpc_pptstabwrite(jas_stream_t *out, jpc_ppxstab_t *tab);
-jpc_ppxstabent_t *jpc_ppxstabent_create();
+jpc_ppxstabent_t *jpc_ppxstabent_create(void);
 void jpc_ppxstabent_destroy(jpc_ppxstabent_t *ent);
 
 int jpc_streamlist_numstreams(jpc_streamlist_t *streamlist);
-jpc_streamlist_t *jpc_streamlist_create();
+jpc_streamlist_t *jpc_streamlist_create(void);
 int jpc_streamlist_insert(jpc_streamlist_t *streamlist, int streamno,
   jas_stream_t *stream);
 jas_stream_t *jpc_streamlist_remove(jpc_streamlist_t *streamlist, int streamno);
@@ -1981,7 +1981,7 @@ void jpc_seglist_remove(jpc_dec_seglist_t *list, jpc_dec_seg_t *seg)
 	seg->next = 0;
 }
 
-jpc_dec_seg_t *jpc_seg_alloc()
+jpc_dec_seg_t *jpc_seg_alloc(void)
 {
 	jpc_dec_seg_t *seg;
 
